==> _private_core_network-1.2.94.tar.gz: lib/network_resources/country/models/currency_available.dart <==
class CurrencyAvailable {
  String? symbol;
  String? thousandSeparator;
  String? decimalSeparator;
  int? decimalPlaces;
  int? symbolPosition;
  String? symbolForBillion;
  String? symbolForMillion;
  String? symbolForThousands;
  int? subUnit;
  String? currencyName;
  String? currencyCode;
  
  bool get isSymbolLeft => symbolPosition == 1;
  bool get isSymbolRight => symbolPosition == 2;

  CurrencyAvailable(
      {this.symbol,
      this.thousandSeparator,
      this.decimalSeparator,
      this.decimalPlaces,
      this.symbolPosition,
      this.symbolForBillion,
      this.symbolForMillion,
      this.symbolForThousands,
      this.subUnit,
      this.currencyName,
      this.currencyCode});

  CurrencyAvailable.fromJson(Map<String, dynamic> json) {
    symbol = json["symbol"];
    thousandSeparator = json["thousandSeparator"];
    decimalSeparator = json["decimalSeparator"];
    decimalPlaces = json["decimalPlaces"];
    symbolPosition = json["symbolPosition"];
    symbolForBillion = json["symbolForBillion"];
    symbolForMillion = json["symbolForMillion"];
    symbolForThousands = json["symbolForThousands"];
    subUnit = json["subUnit"];
    currencyName = json["currencyName"];
    currencyCode = json["currencyCode"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["symbol"] = symbol;
    data["thousandSeparator"] = thousandSeparator;
    data["decimalSeparator"] = decimalSeparator;
    data["decimalPlaces"] = decimalPlaces;
    data["symbolPosition"] = symbolPosition;
    data["symbolForBillion"] = symbolForBillion;
    data["symbolForMillion"] = symbolForMillion;
    data["symbolForThousands"] = symbolForThousands;
    data["subUnit"] = subUnit;
    data["currencyName"] = currencyName;
    data["currencyCode"] = currencyCode;
    return data;
  }

  CurrencyAvailable copyWith({
    String? symbol,
    String? thousandSeparator,
    String? decimalSeparator,
    int? decimalPlaces,
    int? symbolPosition,
    String? symbolForBillion,
    String? symbolForMillion,
    String? symbolForThousands,
    int? subUnit,
    String? currencyName,
    String? currencyCode,
  }) =>
      CurrencyAvailable(
        symbol: symbol ?? this.symbol,
        thousandSeparator: thousandSeparator ?? this.thousandSeparator,
        decimalSeparator: decimalSeparator ?? this.decimalSeparator,
        decimalPlaces: decimalPlaces ?? this.decimalPlaces,
        symbolPosition: symbolPosition ?? this.symbolPosition,
        symbolForBillion: symbolForBillion ?? this.symbolForBillion,
        symbolForMillion: symbolForMillion ?? this.symbolForMillion,
        symbolForThousands: symbolForThousands ?? this.symbolForThousands,
        subUnit: subUnit ?? this.subUnit,
        currencyName: currencyName ?? this.currencyName,
        currencyCode: currencyCode ?? this.currencyCode,
      );
}

==> _private_core_network-1.2.98.tar.gz: lib/network_resources/country/models/currency_available.dart <==
class CurrencyAvailable {
  String? symbol;
  String? thousandSeparator;
  String? decimalSeparator;
  num? decimalPlaces;
  num? symbolPosition;
  String? symbolForBillion;
  String? symbolForMillion;
  String? symbolForThousands;
  num? subUnit;
  String? currencyName;
  String? currencyCode;
  
  bool get isSymbolLeft => symbolPosition == 1;
  bool get isSymbolRight => symbolPosition == 2;

  CurrencyAvailable(
      {this.symbol,
      this.thousandSeparator,
      this.decimalSeparator,
      this.decimalPlaces,
      this.symbolPosition,
      this.symbolForBillion,
      this.symbolForMillion,
      this.symbolForThousands,
      this.subUnit,
      this.currencyName,
      this.currencyCode});

  CurrencyAvailable.fromJson(Map<String, dynamic> json) {
    symbol = json["symbol"];
    thousandSeparator = json["thousandSeparator"];
    decimalSeparator = json["decimalSeparator"];
    decimalPlaces = json["decimalPlaces"];
    symbolPosition = json["symbolPosition"];
    symbolForBillion = json["symbolForBillion"];
    symbolForMillion = json["symbolForMillion"];
    symbolForThousands = json["symbolForThousands"];
    subUnit = json["subUnit"];
    currencyName = json["currencyName"];
    currencyCode = json["currencyCode"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["symbol"] = symbol;
    data["thousandSeparator"] = thousandSeparator;
    data["decimalSeparator"] = decimalSeparator;
    data["decimalPlaces"] = decimalPlaces;
    data["symbolPosition"] = symbolPosition;
    data["symbolForBillion"] = symbolForBillion;
    data["symbolForMillion"] = symbolForMillion;
    data["symbolForThousands"] = symbolForThousands;
    data["subUnit"] = subUnit;
    data["currencyName"] = currencyName;
    data["currencyCode"] = currencyCode;
    return data;
  } 
}
